# v1.0.1
- fix broken link

# v1.0.0
- Added `Jusho` class

# v0.1.0
- Changed drastically
  - Added `Prefecture`, `City` classes
  - Changed Interface

# v0.0.5
- remove printf debug (so sorry)

# v0.0.4
- fixed jusho couldn't be found database file
- update database file
- slight fix of README.md

# v0.0.3
- fixed annotation error

# v0.0.2
- using typing for annotation to fix the typeError on Python Below 3.9

# v0.0.1
- Conception